exceptiontools.MissingMeasureError
==================================

.. abjad-lineage:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError

.. autoclass:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__delattr__
      ~abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__getitem__
      ~abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__getslice__
      ~abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__repr__
      ~abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__setattr__
      ~abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__str__
      ~abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__unicode__

Bases
-----

- :py:class:`exceptions.Exception <exceptions.Exception>`

- :py:class:`exceptions.BaseException <exceptions.BaseException>`

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__unicode__
   :noindex:
